@@ -4,10 +4,12 @@ from enum import Enum, unique
 @unique
 class URL(Enum):
     # 主站地址
-    # DOMAIN = "https://v1.api.juliangip.com"
-    DOMAIN = "http://192.168.10.52:8087"
+    DOMAIN = "https://v1.api.juliangip.com"
+    # DOMAIN = "http://9e84xw.natappfree.cc"
     # 获取账户余额
     USERS_GETBALANCE = DOMAIN + "/users/getbalance"
+    # 获取账户下对应类型的所有正常状态订单
+    USERS_GETALLORDERS = DOMAIN + "/users/getAllOrders"
     # 动态代理 - - 提取动态代理
     DYNAMIC_GETIPS = DOMAIN + "/dynamic/getips"
     # 动态代理 - - 校验IP可用性
